import { AfterContentInit, EventEmitter, QueryList } from '@angular/core';
import { AnimationEvent } from '@angular/animations';
import { Colors } from '../coreui.types';
import { TemplateIdDirective } from '../shared';
import * as i0 from "@angular/core";
type AnimateType = ('hide' | 'show');
export declare class AlertComponent implements AfterContentInit {
    #private;
    hide: boolean;
    /**
     * Sets the color context of the component to one of CoreUI’s themed colors.
     *
     * @type Colors
     * @default 'primary'
     */
    color: Colors;
    /**
     * Default role for alert. [docs]
     * @type string
     * @default 'alert'
     */
    role: string;
    /**
     * Set the alert variant to a solid.
     * @type string
     */
    variant?: 'solid' | string;
    /**
     * Event triggered on the alert dismiss.
     */
    visibleChange: EventEmitter<boolean>;
    templates: any;
    contentTemplates: QueryList<TemplateIdDirective>;
    /**
     * Optionally adds a close button to alert and allow it to self dismiss.
     * @type boolean
     * @default false
     */
    dismissible: boolean;
    /**
     * Adds animation for dismissible alert.
     * @type boolean
     */
    fade: boolean;
    /**
     * Toggle the visibility of alert component.
     * @type boolean
     */
    set visible(value: boolean);
    get visible(): boolean;
    get animationDisabled(): boolean;
    get animateType(): AnimateType;
    get hostClasses(): any;
    onAnimationStart($event: AnimationEvent): void;
    onAnimationDone($event: AnimationEvent): void;
    ngAfterContentInit(): void;
    onAnimationEvent(event: AnimationEvent): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<AlertComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<AlertComponent, "c-alert", ["cAlert"], { "color": { "alias": "color"; "required": false; }; "role": { "alias": "role"; "required": false; }; "variant": { "alias": "variant"; "required": false; }; "dismissible": { "alias": "dismissible"; "required": false; }; "fade": { "alias": "fade"; "required": false; }; "visible": { "alias": "visible"; "required": false; }; }, { "visibleChange": "visibleChange"; }, ["contentTemplates"], ["*"], true, never>;
    static ngAcceptInputType_dismissible: unknown;
    static ngAcceptInputType_fade: unknown;
    static ngAcceptInputType_visible: unknown;
}
export {};
